import frostypy.core
#from . import density
#from . import porosity
#from . import thermal_conductivity
#from . import thickness

#from .core import *
#from .density import * 
#from .porosity import *
#from .thermal_conductivity import * 
#from .thickness import *



#__all__ = ['core', 'density', 'porosity', 'thermal_conductivity', 'thickness']

#__all__.extend(core.__all__)
#__all__.extend(density.__all__)
#__all__.extend(porosity.__all__)
#__all__.extend(thermal_conductivity.__all__)
#__all__.extend(thickness.__all__)



#submodules = (core, density, porosity, thermal_conductivity, thickness)

__version__ = '0.0.15'

def main():
    """Entry point for the application script"""
    print("Call your main application code here")
